@@ -52,9 +52,9 @@
 #' @examples
 #' \donttest{
 #' # The number of adaptSteps, burnInSteps, and numSavedSteps was reduced for package testing
-#' library(DESeq2)
+#' data("cesc")
 #' data(reducedSet)
-#' fit<-ordinalbayes(Stage~1, data=colData(reducedSet),x=t(assay(reducedSet)),
+#' fit<-ordinalbayes(Stage~1, data=cesc, x=cesc[,5:45],
 #'          model="regressvi", gamma.ind="fixed", pi.fixed=0.99,
 #'          adaptSteps=1000, burnInSteps=1000, nChains=2,
 #'          numSavedSteps=2000, thinSteps=2, seed=26)
@@ -62,6 +62,7 @@
 #' @keywords models
 #' @keywords regression
 #' @importFrom stats model.matrix model.response rnorm
+#' @import dclone
 ordinalbayes <-
   function(formula, data, x = NULL, subset, center=TRUE, scale=TRUE, a=0.1, b=0.1, model="regressvi", gamma.ind="fixed", pi.fixed=0.05, c.gamma=NULL, d.gamma=NULL, alpha.var=10,
            sigma2.0=NULL, sigma2.1=NULL, coerce.var=10, lambda0=NULL, nChains=3, adaptSteps=5000, burnInSteps=5000,  numSavedSteps=9999, thinSteps=3, parallel=TRUE, seed=NULL, quiet=FALSE) {
@@ -121,7 +122,7 @@ ordinalbayes <-
       }
       else if (class(x)[1] == "matrix" || class(x)[1] == "data.frame") {
         x <- x[r, , drop = FALSE]
-        x <- as.matrix(x)
+        x <- as.matrix(apply(x, 2, as.numeric))
       }
       P<-dim(x)[2]
       if (scale) {
